2024-06-14 Version: 1.7.0
- Support API DescribeAlertConfiguration.
- Support API ModifyAlertConfiguration.


2024-06-12 Version: 1.6.2
- Update API CreateScalingConfiguration: update param InstancePatternInfos.
- Update API DescribePatternTypes: add param CpuArchitectures.
- Update API DescribePatternTypes: add param GpuSpecs.
- Update API DescribePatternTypes: add param InstanceCategories.
- Update API DescribePatternTypes: add param InstanceTypeFamilies.
- Update API DescribePatternTypes: add param MaximumCpuCoreCount.
- Update API DescribePatternTypes: add param MaximumGpuAmount.
- Update API DescribePatternTypes: add param MaximumMemorySize.
- Update API DescribePatternTypes: add param MinimumBaselineCredit.
- Update API DescribePatternTypes: add param MinimumCpuCoreCount.
- Update API DescribePatternTypes: add param MinimumEniIpv6AddressQuantity.
- Update API DescribePatternTypes: add param MinimumEniPrivateIpAddressQuantity.
- Update API DescribePatternTypes: add param MinimumEniQuantity.
- Update API DescribePatternTypes: add param MinimumGpuAmount.
- Update API DescribePatternTypes: add param MinimumInitialCredit.
- Update API DescribePatternTypes: add param MinimumMemorySize.
- Update API DescribePatternTypes: add param PhysicalProcessorModels.
- Update API DescribeScalingConfigurations: update response param.
- Update API ModifyScalingConfiguration: update param InstancePatternInfos.


2024-05-21 Version: 1.6.1
- Update API DetachInstances: add param IgnoreInvalidInstance.
- Update API RemoveInstances: add param IgnoreInvalidInstance.


2024-05-16 Version: 1.6.0
- Support API DescribePatternTypes.


2024-04-23 Version: 1.5.2
- Update API AttachDBInstances: add param AttachMode.
- Update API AttachDBInstances: add param Type.
- Update API CreateScalingConfiguration: add param DedicatedHostClusterId.
- Update API CreateScalingGroup: add param DBInstances.
- Update API DescribeScalingConfigurations: update response param.
- Update API DescribeScalingGroups: update response param.
- Update API DetachDBInstances: add param RemoveSecurityGroup.
- Update API ModifyScalingConfiguration: add param DedicatedHostClusterId.


2024-04-17 Version: 1.5.1
- Generated python 2022-02-22 for Ess.

2024-03-20 Version: 1.5.0
- Support API ApplyEciScalingConfiguration.
- Support API DescribeEciScalingConfigurationDetail.
- Support API DescribeScalingGroupDetail.
- Support API ModifyInstanceAttribute.
- Update API CreateScalingConfiguration: add param NetworkInterfaces.
- Update API DescribeScalingActivities: update response param.
- Update API DescribeScalingConfigurations: update response param.
- Update API ModifyScalingConfiguration: add param NetworkInterfaces.
- Update API ModifyScalingGroup: add param ScalingPolicy.
- Update API ScaleWithAdjustment: add param ActivityMetadata.
- Update API ScaleWithAdjustment: add param LifecycleHookContext.


2024-03-13 Version: 1.4.0
- Support API ApplyEciScalingConfiguration.
- Support API DescribeEciScalingConfigurationDetail.
- Support API DescribeScalingGroupDetail.
- Support API ModifyInstanceAttribute.
- Update API DescribeScalingActivities: update response param.
- Update API ModifyScalingGroup: add param ScalingPolicy.
- Update API ScaleWithAdjustment: add param ActivityMetadata.
- Update API ScaleWithAdjustment: add param LifecycleHookContext.


2024-02-28 Version: 1.3.0
- Support API ApplyEciScalingConfiguration.
- Support API DescribeEciScalingConfigurationDetail.
- Support API DescribeScalingGroupDetail.
- Support API ModifyInstanceAttribute.
- Update API ModifyScalingGroup: add param ScalingPolicy.


2024-02-22 Version: 1.2.0
- Support API ModifyInstanceAttribute.
- Update API ModifyScalingGroup: add param ScalingPolicy.


2024-02-22 Version: 1.2.0
- Support API ModifyInstanceAttribute.
- Update API ModifyScalingGroup: add param ScalingPolicy.


2024-02-01 Version: 1.1.2
- Update API CreateScalingConfigurationadd CustomPriorities param.
- Update API CreateScalingGroupadd HealthCheckTypes param.
- Update API DescribeScalingConfigurationsupdate response param.
- Update API DescribeScalingGroupsupdate response param.
- Update API ModifyScalingConfigurationadd CustomPriorities param.
- Update API ModifyScalingGroupadd HealthCheckTypes param.


2024-01-29 Version: 1.1.1
- Update API CreateScalingConfigurationadd CustomPriorities param.
- Update API DescribeScalingConfigurationsupdate response param.
- Update API ModifyScalingConfigurationadd CustomPriorities param.


2024-01-23 Version: 1.1.0
- Generated python 2022-02-22 for Ess.

2023-12-25 Version: 1.0.15
- Generated python 2022-02-22 for Ess.

2023-12-06 Version: 1.0.14
- Generated python 2022-02-22 for Ess.

2023-12-04 Version: 1.0.13
- Generated python 2022-02-22 for Ess.

2023-11-17 Version: 1.0.12
- Generated python 2022-02-22 for Ess.

2023-10-18 Version: 1.0.11
- Generated python 2022-02-22 for Ess.

2023-10-18 Version: 1.0.10
- Generated python 2022-02-22 for Ess.

2023-09-19 Version: 1.0.9
- Generated python 2022-02-22 for Ess.

2023-08-23 Version: 1.0.8
- Generated python 2022-02-22 for Ess.

2023-07-20 Version: 1.0.7
- DescribeScalingInstances support creationTypes.

2023-04-19 Version: 1.0.6
- Configuration support LoginAsNonRoot .

2023-03-09 Version: 1.0.5
- Fix the incompatibility of some parameters in the SDK .

2023-02-12 Version: 1.0.4
- CreateScalingGroup and DescribeScalingGroup support NLB server group and new open api AttachServerGroups and DetachServerGroups .

2023-01-13 Version: 1.0.3
- CreateScalingGroup and DescribeScalingGroup support resourcegroup.

2022-10-14 Version: 1.0.2
- Support user custom removal  function policy.

2022-10-14 Version: 1.0.1
- LifecycleHook support disable and enable, ScaleWithAdjustment support scale by instance type.

2022-09-09 Version: 1.0.0
- Ess Tea 2022 SDK release.

